Submitted By:            Pierre Labastie <pierre dot labastie at neuf dot fr>
Date:                    2025-03-07
Initial Package Version: 25.2.1.2
Origin:                  Upstream
Upstream Status:         Committed
Description:             Fix PDF imports with system poppler >= 25.02.0

From 406afe11711df9fcabbc829fcff00aef2f44c1d9 Mon Sep 17 00:00:00 2001
From: Robin Candau <robincandau@protonmail.com>
Date: Thu, 27 Feb 2025 10:26:53 +0100
Subject: tdf#165433 Fix PDF imports with (system) poppler >= 25.02.0

Since poppler 25.02.0, GlobalParams doesn't have a constructor
that accepts a nullptr anymore,
see upstream poppler b50390f748b59cb0a64b912636ecf6527bd0d12a commit.

As such, the data directory location defined for SYSTEM_POPPLER
needs to be updated accordingly (when SYSTEM_POPPLER >= 25.02.0),
otherwise PDF imports fail with
"General Error / General input/output error".

Change-Id: I2a60b03a9ae20aab8d36db2a6827f1f3b9618115
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/182282
Tested-by: Jenkins
Reviewed-by: Xisco Fauli <xiscofauli@libreoffice.org>
---
 sdext/source/pdfimport/xpdfwrapper/wrapper_gpl.cxx | 4 ++++
 1 file changed, 4 insertions(+)

(limited to 'sdext/source/pdfimport/xpdfwrapper/wrapper_gpl.cxx')

diff --git a/sdext/source/pdfimport/xpdfwrapper/wrapper_gpl.cxx b/sdext/source/pdfimport/xpdfwrapper/wrapper_gpl.cxx
index ebed120708cc..9b63559be44d 100644
--- a/sdext/source/pdfimport/xpdfwrapper/wrapper_gpl.cxx
+++ b/sdext/source/pdfimport/xpdfwrapper/wrapper_gpl.cxx
@@ -110,7 +110,11 @@ int main(int argc, char **argv)
 
     /* Get data directory location */
 #ifdef SYSTEM_POPPLER
+#if POPPLER_CHECK_VERSION(25, 2, 0)
+    const std::string datadir = "";
+#else
     const char* datadir = nullptr;
+#endif
 #else
     /* Creates an absolute path to the poppler_data directory, by taking the path
      * to the xpdfimport executable (provided in argv[0], and concatenating a
-- 
cgit v1.2.3

